summaryrefslogtreecommitdiffstats
path: root/src/lib.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib.rs')
-rw-r--r--src/lib.rs5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/lib.rs b/src/lib.rs
index bed60b4..b6eb0f6 100644
--- a/src/lib.rs
+++ b/src/lib.rs
@@ -5,7 +5,7 @@
//! - Environment variables
//! - Another Config instance
//! - Remote configuration: etcd, Consul
//! - Files: JSON, YAML, TOML
//! - Manual, programmatic override (via a `.set` method on the Config instance)
//!
//! Additionally, Config supports:
@@ -38,6 +38,9 @@ extern crate serde_json;
#[cfg(feature = "yaml")]
extern crate yaml_rust;
+#[cfg(feature = "hjson")]
+extern crate serde_hjson;
+
mod error;
mod value;
mod de;
@@ -5,7 +5,7 @@
//! - Another Config instance
//! - Remote configuration: etcd, Consul
-//! - Files: JSON, YAML, TOML
+//! - Files: JSON, YAML, TOML, HJSON
//! - Manual, programmatic override (via a `.set` method on the Config instance)
//!